!---------------------------------------------------------------------------------------
! PREP_FLUXES: calc_monthly
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> calc_monthly
!!
!! Purpose:    Calculates a monthly flux using annual mean and temporal variability
!!             factors.
!!
!! Interface:
!!
!!    Inputs
!!             settings  -  settings data structure 
!!             flx_in    -  input flux with ntime time dimension
!!  
!!    Outputs
!!             flx_tmp   -  input flux expanded to ntime_out
!!
!!    Externals
!!             read_ncdf
!!
!---------------------------------------------------------------------------------------

subroutine calc_monthly(settings, flx_in, flx_tmp)

  use mod_var
  use mod_settings

  implicit none

  type (settings_t),                      intent(in)     :: settings
  real, dimension(nx_in,ny_in,ntime),     intent(in)     :: flx_in
  real, dimension(nx_in,ny_in,ntime_out), intent(in out) :: flx_tmp

  character(len=max_name_len)            :: filename, varname, lonname, latname, timename
  real, dimension(ntime)                 :: time
  real, dimension(nx_in)                 :: lon
  real, dimension(ny_in)                 :: lat
  real, dimension(nx_in,ny_in,ntime_out) :: scalar
  integer :: nt

  ! read scalars from ncdf file

  filename = settings%file_scalar
  varname = settings%varname_scalar
  lonname = settings%lonname_scalar
  latname = settings%latname_scalar
  timename = settings%timename_scalar

  call read_ncdf(filename, varname, lonname, latname, timename,&
                  1, time, lon, lat, scalar)   
 
  ! scale fluxes
 
  if (ntime.eq.ntime_out) then
    do nt = 1, ntime_out
      flx_tmp(:,:,nt) = flx_in(:,:,nt)*scalar(:,:,nt)
    end do
  else if(ntime.eq.1) then
    do nt = 1, ntime_out
      flx_tmp(:,:,nt) = flx_in(:,:,1)*scalar(:,:,nt)
    end do  
  else
     write(*,*) 'ERROR: incompatible ntime and ntime_out'
     stop
  endif

end subroutine calc_monthly

